@@ -1,10 +1,12 @@
 /** @format */
 
+import { promisify } from "@/promisify";
 import { h, inject, ref } from "vue";
 import { useI18n } from "vue-i18n";
 
+import { createServerUIMachine } from "./ServerUI.machines.js";
+
 const registry = require("dijit/registry");
-const parser = require("dojo/parser");
 const query = require("dojo/query");
 const topic = require("dojo/topic");
 
@@ -18,6 +20,7 @@ function domReject(response) {
 }
 
 export default {
+    name: "ServerUI",
     setup() {
         const { t } = useI18n();
         const notify = inject("notify");
@@ -33,90 +36,18 @@ export default {
         }
     },
     methods: {
-        async updateContent(tgt, options = {}) {
-            let dismiss;
-            try {
-                this.notify({
-                    title: options.doing || this.$t("Loading..."),
-                    type: "info",
-                    dismissReceiver: (cb) => {
-                        dismiss = cb;
-                    }
-                });
-                let headers = new Headers(options.headers);
-                headers.set("X-Requested-With", "XMLHttpRequest");
-
-                document
-                    .getElementById("maindiv")
-                    .removeAttribute("data-lsmb-done");
-                // chop off the leading '/' to use relative paths
-                let base = window.location.pathname.replace(/[^/]*$/, "");
-                let relTgt =
-                    tgt.substring(0, 1) === "/" ? tgt.substring(1) : tgt;
-                let r = await fetch(base + relTgt, {
-                    method: options.method,
-                    body: options.data,
-                    headers: headers
-                    // additional parameters to consider:
-                    // mode(cors?), credentials, referrerPolicy?
-                });
-
-                if (r.ok && !domReject(r)) {
-                    let newContent = await r.text();
-                    this.notify({
-                        title: options.done || this.$t("Loaded")
-                    });
-                    if (newContent === this.content) {
-                        // when there is no difference in returned content,
-                        // Vue won't re-render... so don't rerun the parser!
-                        return;
-                    }
-                    this._cleanWidgets();
-                    this.content = newContent;
-                    this.$nextTick(() => {
-                        let maindiv = document.getElementById("maindiv");
-                        parser.parse(maindiv).then(
-                            () => {
-                                registry
-                                    .findWidgets(maindiv)
-                                    .forEach((child) => {
-                                        this.recursivelyResize(child);
-                                    });
-                                maindiv
-                                    .querySelectorAll("a")
-                                    .forEach((node) =>
-                                        this._interceptClick(node)
-                                    );
-                                if (dismiss) {
-                                    dismiss();
-                                }
-                                topic.publish("lsmb/page-fresh-content");
-                                maindiv.setAttribute("data-lsmb-done", "true");
-                                this._setFormFocus();
-                            },
-                            (e) => {
-                                this.reportError(e);
-                            }
-                        );
-                    });
-                } else {
-                    this.reportError(r);
-                }
-            } catch (e) {
-                this.reportError(e);
-            } finally {
-                if (dismiss) {
-                    dismiss();
-                }
-            }
+        updateContent(tgt, options = {}) {
+            this.machine.send({ type: "loadContent", value: { tgt, options } });
         },
         _setFormFocus() {
             [...document.forms].forEach((form) => {
                 if (form.hasAttribute("data-lsmb-focus")) {
                     let focus = form.getAttribute("data-lsmb-focus");
-                    let elm = document.getElementById(focus);
-                    if (elm) {
-                        elm.select();
+                    if (focus) {
+                        let elm = document.getElementById(focus);
+                        if (elm) {
+                            elm.select();
+                        }
                     }
                 }
             });
@@ -147,7 +78,7 @@ export default {
 
             let d = registry.byId("errorDialog");
             d.set("content", errstr);
-            d.show();
+            await promisify(d.show());
         },
         _interceptClick(dnode) {
             let href = dnode.getAttribute("href");
@@ -188,7 +119,23 @@ export default {
         }
     },
     beforeRouteLeave() {
-        this._cleanWidgets();
+        this.machine.send("unloadContent");
+        return this.machine.state.value === "unloaded";
+    },
+    created() {
+        let maindiv = document.getElementById("maindiv");
+        this.machine = createServerUIMachine(
+            {
+                notify: this.notify,
+                view: this
+            },
+            ({ machine }) => {
+                if (machine.current === "idle") {
+                    topic.publish("lsmb/page-fresh-content");
+                    maindiv.setAttribute("data-lsmb-done", "true");
+                }
+            }
+        );
     },
     mounted() {
         document
