@@ -268,7 +268,6 @@ use Log::Any;
 use PGObject;
 use Plack;
 use URI;
-use URI::Escape;
 
 use LedgerSMB::Locale;
 use LedgerSMB::PGDate;
@@ -278,7 +277,7 @@ use LedgerSMB::Setting;
 use LedgerSMB::Template;
 use LedgerSMB::User;
 
-our $VERSION = '1.12.16';
+our $VERSION = '1.13.1';
 
 my $logger = Log::Any->get_logger(category => 'LedgerSMB');
 my $expiration_parser = DateTime::Format::Duration::ISO8601->new;
@@ -365,13 +364,11 @@ sub initialize_with_db {
     $sth->execute or die $sth->errstr;
     ($self->{warn_expire}) = $sth->fetchrow_array;
 
-    if ($self->{warn_expire}){
-        $sth = $self->{dbh}->prepare('SELECT user__check_my_expiration()')
-            or die $self->{dbh}->errstr;
-        $sth->execute or die $sth->errstr;
-        my ($pw_expires) = $sth->fetchrow_array;
-        $self->{pw_expires} = $expiration_parser->parse_duration($pw_expires);
-    }
+    $sth = $self->{dbh}->prepare('SELECT user__check_my_expiration()')
+        or die $self->{dbh}->errstr;
+    $sth->execute or die $sth->errstr;
+    my ($pw_expires) = $sth->fetchrow_array;
+    $self->{pw_expires} = $expiration_parser->parse_duration($pw_expires);
 
     $self->get_user_info;
 
@@ -399,7 +396,7 @@ sub _set_default_locale {
         ->from_header( $self->{_req}->header( 'Accept-Language' ) );
 
     $self->{_user}->{language} = $lang;
-    $self->{_user}->{dateformat} = 'YYYY-MM-DD';
+    $self->{_user}->{dateformat} = 'yyyy-mm-dd';
     $self->{_user}->{numberformat} = '1000.00';
     $self->{_locale}=LedgerSMB::Locale->get_handle($lang);
     $self->error( __FILE__ . ':' . __LINE__
