@@ -14,10 +14,9 @@ The type behaves internally as a Datetime module.
 
 =cut
 
-use v5.36;
+use v5.36.1;
 use warnings;
-use base qw(PGObject::Type::DateTime);
-use Scalar::Util qw(blessed);
+use parent qw(PGObject::Type::DateTime);
 
 use Carp;
 use DateTime;
@@ -201,7 +200,7 @@ sub from_input{
     my $self = shift;
     my $input = shift;
 
-    return $input if blessed $input and $input->isa( __PACKAGE__ ) and $input->is_date;
+    return $input if $input isa __PACKAGE__ && $input->is_date;
     return __PACKAGE__->new()
         if ! $input; # matches undefined as well as ''
 
@@ -251,14 +250,9 @@ memoize('_formatter');
 # Provide a stringification routine instead of the one inherited
 use overload (
     fallback => 1,
-    q{""}    => '_stringification',
+    q{""}    => 'to_output',
 );
 
-sub _stringification {
-    # drop the second and third parameters before calling to_output()
-    return $_[0]->to_output();
-}
-
 sub to_output {
     my $self = shift @_;
     return '' if not $self->is_date();
