@@ -28,7 +28,7 @@ use LedgerSMB::Business_Unit_Class;
 use LedgerSMB::Business_Unit;
 use LedgerSMB::I18N;
 
-use List::Util qw(none);
+use List::Util qw(none sum);
 
 
 has 'languages' => (is => 'ro',
@@ -91,12 +91,6 @@ sub columns {
     }
 
     push @COLUMNS,
-      {col_id => 'select',
-         type => 'checkbox',
-         name => 'X',
-       toggle => 1,
-      },
-
       {col_id => 'name',
          name => $credit_label,
          type => 'text',
@@ -111,7 +105,13 @@ sub columns {
          name => $self->Text('Language'),
          type => 'select',
       options => $self->languages,
-       pwidth => '0', };
+       pwidth => '0', },
+
+      {col_id => 'select',
+         type => 'checkbox',
+         name => 'X',
+       toggle => 1,
+      };
 
    if ($self->report_type eq 'detail'){
      push @COLUMNS,
@@ -138,35 +138,42 @@ sub columns {
     }
 
     push @COLUMNS,
-    {col_id => 'c0',
+    {col_id => 'c0_tc',
        name => $self->Text('Current'),
        type => 'text',
       money => 1,
      pwidth => '2', },
 
-    {col_id => 'c30',
+    {col_id => 'c30_tc',
        name => '30',
        type => 'text',
       money => 1,
      pwidth => '3', },
 
-    {col_id => 'c60',
+    {col_id => 'c60_tc',
        name => '60',
        type => 'text',
       money => 1,
      pwidth => '3', },
 
-    {col_id => 'c90',
+    {col_id => 'c90_tc',
        name => '90',
        type => 'text',
       money => 1,
      pwidth => '3', },
 
-    {col_id => 'total',
+    {col_id => 'total_tc',
        name => $self->Text('Total'),
        type => 'text',
       money => 1,
-     pwidth => '1', };
+     pwidth => '3', },
+
+      {col_id => 'curr',
+         name => $self->Text('Currency'),
+         type => 'text',
+       pwidth => '1', };
+
+
     return \@COLUMNS;
 }
 
@@ -234,7 +241,7 @@ Calculate report as on a specific date
 
 =cut
 
-has 'to_date'=> (is => 'rw', coerce => 1, isa => 'LedgerSMB::Moose::Date');
+has 'to_date'=> (is => 'rw', isa => 'LedgerSMB::PGDate');
 
 =item entity_class
 
@@ -276,6 +283,8 @@ has c60total => (is => 'rw', init_arg => undef);
 has c90total => (is => 'rw', init_arg => undef);
 has total => (is => 'rw', init_arg => undef);
 
+has '+show_totals' => (default => 0);
+
 =back
 
 =head1 METHODS
@@ -293,41 +302,103 @@ sub run_report{
     my @rows = $self->call_dbmethod(funcname => 'report__invoice_aging_' .
                                                 $self->report_type);
     my @result;
-    my %row_span;
+    my %account_rowspan;
+    my %curr_rowspan;
+    my $curr_subtotals = {
+        c0 => 0, c30 => 0, c60 => 0, c90 => 0, total => 0,
+        c0_tc => 0, c30_tc => 0, c60_tc => 0, c90_tc => 0, total_tc => 0
+    };
+    my $last_curr_sec = '';
+    my $last_sec = '';
     for my $row (@rows) {
         next if ($self->has_details_filter
                  and none { $_ == $row->{id} } $self->details_filter->@*);
-        $row->{language} //= $self->language;
-        push @result, $row;
-
         if ($self->report_type eq 'detail') {
-            $row_span{"$row->{account_number}:$row->{entity_id}"} //= 0;
-            $row_span{"$row->{account_number}:$row->{entity_id}"}++;
-            $row->{row_id} =
-                "$row->{account_number}:$row->{entity_id}:$row->{id}";
+            my $sec = "$row->{account_number}:$row->{entity_id}";
+            my $curr_sec = "$sec:$row->{curr}";
+            if ($last_curr_sec ne $curr_sec) {
+                if ($last_curr_sec) {
+                    $account_rowspan{$last_sec} //= 0;
+                    $account_rowspan{$last_sec}++;
+
+                    # $curr_rowspan{$last_curr_sec} //= 0;
+                    # $curr_rowspan{$last_curr_sec}++;
+                    push @result, $curr_subtotals;
+                }
+                $curr_subtotals = {
+                    c0 => 0, c30 => 0, c60 => 0, c90 => 0, total => 0,
+                    c0_tc => 0, c30_tc => 0, c60_tc => 0, c90_tc => 0, total_tc => 0,
+                    invnumber => '',
+                    invnumber_NOHREF => 1,
+                    html_class => 'listsubtotal',
+                    $row->%{qw( account_number entity_id curr )},
+                };
+            }
+
+            $account_rowspan{$sec} //= 0;
+            $account_rowspan{$sec}++;
+
+            # $curr_rowspan{$curr_sec} //= 0;
+            # $curr_rowspan{$curr_sec}++;
+
+            $row->{row_id} = "$sec:$row->{id}";
+            $last_curr_sec = $curr_sec;
+            $last_sec = $sec;
         } else {
             $row->{row_id} = "$row->{account_number}:$row->{entity_id}";
         }
+
+        $row->{language} //= $self->language;
+        $row->{total} = sum map { $row->{$_} } qw/ c0 c30 c60 c90 /;
+        $row->{total_tc} = sum map { $row->{"${_}_tc"} } qw/ c0 c30 c60 c90 /;
+
+        $curr_subtotals->{$_} += $row->{$_} for (qw/ c0 c30 c60 c90 total /);
+        $curr_subtotals->{"${_}_tc"} += $row->{"${_}_tc"} for (qw/ c0 c30 c60 c90 total /);
         $self->c0total($self->c0total + $row->{c0});
         $self->c30total($self->c30total + $row->{c30});
         $self->c60total($self->c60total + $row->{c60});
         $self->c90total($self->c90total + $row->{c90});
-        $row->{total} = $row->{c0} + $row->{c30} + $row->{c60} + $row->{c90};
+
         $self->total($self->total + $row->{total});
+
+        push @result, $row;
     }
-    if (%row_span) {
+    if ($last_curr_sec) {
+        $account_rowspan{$last_sec} //= 0;
+        $account_rowspan{$last_sec}++;
+
+        # $curr_rowspan{$last_curr_sec} //= 0;
+        # $curr_rowspan{$last_curr_sec}++;
+        push @result, $curr_subtotals;
+    }
+    else {
+        $curr_subtotals->@{qw( html_class )} = ('listtotal');
+        push @result, $curr_subtotals;
+    }
+    if (%account_rowspan) {
         for my $row (@result) {
-            if ($row_span{"$row->{account_number}:$row->{entity_id}"} > 1) {
-                $row->{language_ROWSPAN} = $row_span{"$row->{account_number}:$row->{entity_id}"};
+            my $sec = "$row->{account_number}:$row->{entity_id}";
+            my $account_span = $account_rowspan{$sec} // 0;
+            if ($account_span > 1) {
+                $row->{language_ROWSPAN} = $account_span;
                 $row->{name_ROWSPAN} = $row->{language_ROWSPAN};
                 $row->{account_number_ROWSPAN} = $row->{language_ROWSPAN};
-                $row_span{"$row->{account_number}:$row->{entity_id}"} *= -1;
+                $account_rowspan{$sec} *= -1;
             }
-            elsif ($row_span{"$row->{account_number}:$row->{entity_id}"} < 0) {
+            elsif ($account_rowspan{$sec} < 0) {
                 $row->{language_ROWSPANNED} = 1;
                 $row->{name_ROWSPANNED} = 1;
                 $row->{account_number_ROWSPANNED} = 1;
             }
+
+            my $curr_span = $curr_rowspan{"$sec:$row->{curr}"} // 0;
+            if ($curr_span > 1) {
+                $row->{curr_ROWSPAN} = $curr_span;
+                $curr_rowspan{"$sec:$row->{curr}"} *= -1;
+            }
+            elsif ($curr_span < 0) {
+                $row->{curr_ROWSPANNED} = 1;
+            }
         }
     }
     return $self->rows(\@result);
@@ -337,7 +408,7 @@ sub run_report{
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2012-2023 The LedgerSMB Core Team
+Copyright (C) 2012-2024 The LedgerSMB Core Team
 
 This file is licensed under the GNU General Public License version 2, or at your
 option any later version.  A copy of the license should have been included with
