@@ -99,7 +99,7 @@ sub _get_sic {
 sub _get_sics {
     my ($c, $formatter) = @_;
     my $sth = $c->dbh->prepare(
-        q|SELECT * FROM sic ORDER BY code|
+        q|SELECT *, md5(last_updated::text) as etag FROM sic ORDER BY code|
         ) or die $c->dbh->errstr;
 
     $sth->execute() or die $sth->errstr;
@@ -108,6 +108,7 @@ sub _get_sics {
         push @results, {
             code => $row->{code},
             description => $row->{description},
+            _meta => { ETag => $row->{etag} }
         };
     }
     die $sth->errstr if $sth->err;
@@ -166,7 +167,7 @@ get api '/contacts/sic' => sub {
             _dbh => $c->dbh,
             language => 'en',
             );
-        my $renderer = $formatter->report_doc_renderer( $c->dbh, $format );
+        my $renderer = $formatter->report_doc_renderer( $c->dbh, {}, $format );
 
         return template_response( $report->render( renderer => $renderer ),
                                   disposition => 'attach');
@@ -384,7 +385,7 @@ get api '/contacts/business-types' => sub {
             _dbh => $c->dbh,
             language => 'en',
             );
-        my $renderer = $formatter->report_doc_renderer( $c->dbh, $format );
+        my $renderer = $formatter->report_doc_renderer( $c->dbh, {}, $format );
 
         return template_response( $report->render( renderer => $renderer ),
                                   disposition => 'attach');
@@ -508,8 +509,9 @@ paths:
                     type: array
                     items:
                       $ref: '#/components/schemas/SIC'
-                    example:
-                      $ref: '#/components/examples/validSIC'
+              examples:
+                validSICs:
+                  $ref: '#/components/examples/validSICs'
         400:
           $ref: '#/components/responses/400'
         401:
@@ -697,8 +699,9 @@ paths:
                     type: array
                     items:
                       $ref: '#/components/schemas/BusinessType'
-                    example:
-                      $ref: '#/components/examples/validBusinessType'
+              examples:
+                validBusinessTypes:
+                  $ref: '#/components/examples/validBusinessTypes'
         400:
           $ref: '#/components/responses/400'
         401:
@@ -877,12 +880,29 @@ components:
       schema:
         type: string
   examples:
+    validSICs:
+      summary: Valid SICs (collection response)
+      description: SIC collection response
+      value:
+        _links: []
+        items:
+        - code: "541510"
+          description: Design of computer systems
     validSIC:
       summary: Valid SIC
       description: Standard Industry Code
       value:
         code: "541510"
         description: Design of computer systems
+    validBusinessTypes:
+      summary: Valid Business Types (collection response)
+      description: Business Types collection response
+      value:
+        _links: []
+        items:
+        - id: 1
+          description: Big customer
+          discount: 0.05
     validBusinessType:
       summary: Valid Business Type
       description: Business Type Entry
