@@ -24,6 +24,7 @@ use warnings;
 use HTTP::Status qw( HTTP_OK HTTP_NO_CONTENT HTTP_CREATED HTTP_CONFLICT HTTP_FORBIDDEN );
 
 use LedgerSMB::PSGI::Util qw( template_response );
+use LedgerSMB::Report::Inventory::Partsgroups;
 use LedgerSMB::Report::Inventory::Pricegroups;
 use LedgerSMB::Report::Listings::Warehouse;
 use LedgerSMB::Router appname => 'erp/api';
@@ -33,6 +34,228 @@ set logger => 'erp.api.products';
 set api_schema => openapi_schema(\*DATA);
 
 
+##############################################################################
+#
+#
+#     PARTSGROUPS
+#
+#
+#############################################################################
+
+sub _add_partsgroup {
+    my ($c, $w) = @_;
+    my $sth = $c->dbh->prepare(
+        q|INSERT INTO partsgroup (parent, partsgroup) VALUES (?, ?)
+          RETURNING id, parent, partsgroup as description, md5(last_updated::text) as etag|
+        ) or die $c->dbh->errstr;
+
+    $sth->execute( $w->{parent}, $w->{description} ) or die $sth->errstr;
+    my $row = $sth->fetchrow_hashref('NAME_lc');
+    die $sth->errstr if $sth->err;
+
+    return (
+        {
+            id => $row->{id},
+            parent => $row->{parent},
+            description => $row->{description}
+        },
+        {
+            ETag => $row->{etag}
+        });
+}
+
+sub _del_partsgroup {
+    my ($c, $id) = @_;
+    my $sth = $c->dbh->prepare(
+        q|DELETE FROM partsgroup WHERE id = ?|
+        ) or die $c->dbh->errstr;
+
+    $sth->execute( $id ) or die $sth->errstr;
+    return undef unless $sth->rows > 0;
+
+    return 1;
+}
+
+sub _get_partsgroup {
+    my ($c, $id) = @_;
+    my $sth = $c->dbh->prepare(
+        q|SELECT id, parent, partsgroup as description,
+                 md5(last_updated::text) as etag FROM partsgroup WHERE id = ?|
+        ) or die $c->dbh->errstr;
+
+    $sth->execute($id) or die $sth->errstr;
+    my $row = $sth->fetchrow_hashref('NAME_lc');
+    die $sth->errstr if $sth->err;
+
+    return undef unless $row;
+    return (
+        {
+            id => $row->{id},
+            parent => $row->{parent},
+            description => $row->{description},
+        },
+        {
+            ETag => $row->{etag}
+        });
+}
+
+sub _get_partsgroups {
+    my ($c, $formatter) = @_;
+    my $sth = $c->dbh->prepare(
+        q|SELECT id, parent, partsgroup as description,
+                 md5(last_updated::text) as etag
+          FROM partsgroup ORDER BY id|
+        ) or die $c->dbh->errstr;
+
+    $sth->execute() or die $sth->errstr;
+    my @results;
+    while (my $row = $sth->fetchrow_hashref('NAME_lc')) {
+        push @results, {
+            id => $row->{id},
+            parent => $row->{parent},
+            description => $row->{description},
+            _meta => { ETag => $row->{etag} }
+        };
+    }
+    die $sth->errstr if $sth->err;
+
+    return {
+        items => \@results,
+        _links => [
+            map {
+                +{
+                    rel => 'download',
+                    href => "?format=$_",
+                    title => $_
+                }
+            } $formatter->get_formats->@* ]
+    };
+}
+
+sub _update_partsgroup {
+    my ($c, $w, $m) = @_;
+    my $sth = $c->dbh->prepare(
+        q|UPDATE partsgroup SET partsgroup = ?
+           WHERE id = ? AND md5(last_updated::text) = ?
+          RETURNING id, parent, partsgroup as description, md5(last_updated::text) as etag|
+        ) or die $c->dbh->errstr;
+
+    $sth->execute( $w->{description}, $w->{id}, $m->{ETag} ) or die $sth->errstr;
+    if ($sth->rows == 0) {
+        my ($response, $meta) = _get_partsgroup($c, $w->{id});
+        return (undef, {}) unless $response;
+
+        # Obviously, the hashes must have mismatched
+        return (undef, { conflict => 1 });
+    }
+
+    my $row = $sth->fetchrow_hashref('NAME_lc');
+    die $sth->errstr if $sth->err;
+
+    return (
+        {
+            id => $row->{id},
+            parent => $row->{parent},
+            description => $row->{description}
+        },
+        {
+            ETag => $row->{etag}
+        });
+}
+
+get api '/products/partsgroups' => sub {
+    my ($env, $r, $c, $body, $params) = @_;
+    my $formatter = $env->{wire}->get( 'output_formatter' );
+
+    if (my $format = $r->query_parameters->get('format')) {
+        my $report = LedgerSMB::Report::Inventory::Partsgroups->new(
+            _dbh => $c->dbh,
+            language => 'en',
+            );
+        my $renderer = $formatter->report_doc_renderer( $c->dbh, {}, $format );
+
+        return template_response( $report->render( renderer => $renderer ),
+                                  disposition => 'attach');
+    }
+
+    my $response = _get_partsgroups( $c, $formatter );
+    return [ HTTP_OK,
+             [ 'Content-Type' => 'application/json; charset=UTF-8' ],
+             $response  ];
+};
+
+post api '/products/partsgroups' => sub {
+    my ($env, $r, $c, $body, $params) = @_;
+
+    my ($response, $meta) = _add_partsgroup( $c, $body );
+    return [
+        HTTP_CREATED,
+        [ 'Content-Type' => 'application/json; charset=UTF-8',
+          'ETag' => qq|"$meta->{ETag}"|
+        ],
+        $response ];
+};
+
+del api '/products/partsgroups/{id}' => sub {
+    my ($env, $r, $c, $body, $params) = @_;
+
+    #my $response = _del_partsgroup( $c, $params->{id} );
+
+    # return 'undef' if $response is undef, which it is when not found
+    return [ HTTP_FORBIDDEN, [ ], [ '' ] ];
+};
+
+get api '/products/partsgroups/{id}' => sub {
+    my ($env, $r, $c, $body, $params) = @_;
+
+    return undef if !$params->{id};
+    my ($response, $meta) = _get_partsgroup( $c, $params->{id} );
+
+    return $response && [ HTTP_OK,
+             [ 'Content-Type' => 'application/json; charset=UTF-8',
+               'ETag' => qq|"$meta->{ETag}"| ],
+             $response ];
+};
+
+
+put api '/products/partsgroups/{id}' => sub {
+    my ($env, $r, $c, $body, $params) = @_;
+
+    $env->{'psgix.logger'}->({
+        message => "PUT /products/partsgroups/$params->{id}",
+        level => 'info' });
+    my ($ETag) = ($r->headers->header('If-Match') =~ m/^\s*(?>W\/)?"(.*)"\s*$/);
+    my ($response, $meta) = _update_partsgroup(
+        $c, {
+            id => $params->{id},
+            description => $body->{description}
+        },
+        {
+            ETag => $ETag
+        });
+
+    return [ HTTP_CONFLICT, [], [ '' ] ]
+        if ($meta->{conflict});
+
+    return [ HTTP_OK,
+             [ 'Content-Type' => 'application/json; charset=UTF-8',
+               'ETag' => qq|"$meta->{ETag}"| ],
+             $response ];
+};
+
+patch api '/products/partsgroups/{id}' => sub {
+    my ($env, $r, $c, $body, $params) = @_;
+    my $type = ($r->parameters->{type} // '') =~ s/[*]//gr;
+    my $partnumber = ($r->parameters->{partnumber} // '') =~ s/[*]//gr;
+    my $description = ($r->parameters->{description} // '') =~ s/[*]//gr;
+
+    return [ HTTP_OK, [ 'Content-Type' => 'application/json; charset=UTF-8' ],
+             [ json()->encode(
+                   0
+               ) ] ];
+};
+
+
 ##############################################################################
 #
 #
@@ -138,7 +361,7 @@ sub _update_pricegroup {
 
     $sth->execute( $w->{description}, $w->{id}, $m->{ETag} ) or die $sth->errstr;
     if ($sth->rows == 0) {
-        my ($response, $meta) = _get_warehouse($c, $w->{id});
+        my ($response, $meta) = _get_pricegroup($c, $w->{id});
         return (undef, {}) unless $response;
 
         # Obviously, the hashes must have mismatched
@@ -478,6 +701,193 @@ your software.
 
 __DATA__
 paths:
+  /products/partsgroups:
+    description: Managing products and related configuration
+    get:
+      tags:
+        - Parts groups
+      summary: Get products parts groups
+      operationId: getProductsPartsgroups
+      responses:
+        200:
+          description: Returns the full list of defined parts groups
+          content:
+            application/json:
+              schema:
+                type: object
+                required:
+                  - items
+                properties:
+                  _links:
+                    type: array
+                    items:
+                      type: object
+                  items:
+                    type: array
+                    items:
+                      $ref: '#/components/schemas/Partsgroup'
+              examples:
+                validPartsgroups:
+                  $ref: '#/components/examples/validPartsgroups'
+        400:
+          $ref: '#/components/responses/400'
+        401:
+          $ref: '#/components/responses/401'
+        403:
+          $ref: '#/components/responses/403'
+        404:
+          $ref: '#/components/responses/404'
+    post:
+      tags:
+        - Parts groups
+      summary: Create products parts group
+      operationId: postProductsPartsgroup
+      requestBody:
+        content:
+          application/json:
+            schema:
+              $ref: '#/components/schemas/NewPartsgroup'
+      responses:
+        201:
+          description: |
+            Confirms creation of the new resource, returning
+            the new data
+          headers:
+            ETag:
+              $ref: '#/components/headers/ETag'
+            Location:
+              schema:
+                type: string
+                format: uri-reference
+        400:
+          $ref: '#/components/responses/400'
+        401:
+          $ref: '#/components/responses/401'
+        403:
+          $ref: '#/components/responses/403'
+        404:
+          $ref: '#/components/responses/404'
+  /products/partsgroups/{id}:
+    parameters:
+      - name: id
+        in: path
+        required: true
+        schema:
+          $ref: '#/components/schemas/partsgroup-id'
+        style: simple
+    get:
+      tags:
+        - Parts groups
+      summary: Get a single products parts group
+      operationId: getProductsPartsgroupById
+      responses:
+        200:
+          description: |
+            Returns the data for a single resource
+          headers:
+            ETag:
+              $ref: '#/components/headers/ETag'
+          content:
+            application/json:
+              schema:
+                $ref: '#/components/schemas/Partsgroup'
+              examples:
+                validPartsgroup:
+                  $ref: '#/components/examples/validPartsgroup'
+        304:
+          $ref: '#/components/responses/304'
+        400:
+          $ref: '#/components/responses/400'
+        401:
+          $ref: '#/components/responses/401'
+        403:
+          $ref: '#/components/responses/403'
+        404:
+          $ref: '#/components/responses/404'
+    put:
+      tags:
+        - Parts groups
+      summary: Create single products parts group
+      operationId: putProductsPartsgroupById
+      parameters:
+        - $ref: '#/components/parameters/if-match'
+      requestBody:
+        content:
+          application/json:
+            schema:
+              $ref: '#/components/schemas/Partsgroup'
+      responses:
+        200:
+          description: |
+            Confirms successful replacement of the
+            resource's data, returning the new state
+          headers:
+            ETag:
+              $ref: '#/components/headers/ETag'
+          content:
+            application/json:
+              schema:
+                $ref: '#/components/schemas/Partsgroup'
+        304:
+          $ref: '#/components/responses/304'
+        400:
+          $ref: '#/components/responses/400'
+        401:
+          $ref: '#/components/responses/401'
+        403:
+          $ref: '#/components/responses/403'
+        404:
+          $ref: '#/components/responses/404'
+        409:
+          $ref: '#/components/responses/409'
+        412:
+          $ref: '#/components/responses/412'
+        413:
+          $ref: '#/components/responses/413'
+        428:
+          $ref: '#/components/responses/428'
+    delete:
+      tags:
+        - Parts groups
+      summary: Delete a single products price group
+      operationId: deleteProductsPartsgroupById
+      parameters:
+        - $ref: '#/components/parameters/if-match'
+      responses:
+        204:
+          description: Confirms successful deletion of the resource
+        400:
+          $ref: '#/components/responses/400'
+        401:
+          $ref: '#/components/responses/401'
+        403:
+          $ref: '#/components/responses/403'
+        404:
+          $ref: '#/components/responses/404'
+        409:
+          $ref: '#/components/responses/409'
+    patch:
+      tags:
+        - Parts groups
+      summary: Updaet a single products parts group
+      operationId: updateProductsPartsgroupById
+      parameters:
+        - $ref: '#/components/parameters/if-match'
+      responses:
+        200:
+          description: |
+            Confirms successful update of the resource,
+            returning the new resource state
+        400:
+          $ref: '#/components/responses/400'
+        401:
+          $ref: '#/components/responses/401'
+        403:
+          $ref: '#/components/responses/403'
+        404:
+          $ref: '#/components/responses/404'
+        409:
+          $ref: '#/components/responses/409'
   /products/pricegroups:
     description: Managing products and related configuration
     get:
@@ -615,6 +1025,8 @@ paths:
           $ref: '#/components/responses/403'
         404:
           $ref: '#/components/responses/404'
+        409:
+          $ref: '#/components/responses/409'
         412:
           $ref: '#/components/responses/412'
         413:
@@ -639,6 +1051,8 @@ paths:
           $ref: '#/components/responses/403'
         404:
           $ref: '#/components/responses/404'
+        409:
+          $ref: '#/components/responses/409'
     patch:
       tags:
         - Price groups
@@ -659,6 +1073,8 @@ paths:
           $ref: '#/components/responses/403'
         404:
           $ref: '#/components/responses/404'
+        409:
+          $ref: '#/components/responses/409'
   /products/warehouses:
     description: Manage warehouses
     get:
@@ -796,6 +1212,8 @@ paths:
           $ref: '#/components/responses/403'
         404:
           $ref: '#/components/responses/404'
+        409:
+          $ref: '#/components/responses/409'
         412:
           $ref: '#/components/responses/412'
         413:
@@ -820,6 +1238,8 @@ paths:
           $ref: '#/components/responses/403'
         404:
           $ref: '#/components/responses/404'
+        409:
+          $ref: '#/components/responses/409'
     patch:
       tags:
         - Warehouses
@@ -840,12 +1260,37 @@ paths:
           $ref: '#/components/responses/403'
         404:
           $ref: '#/components/responses/404'
+        409:
+          $ref: '#/components/responses/409'
 components:
   schemas:
     common-id:
       type: integer
       format: int64
       minimum: 1
+    partsgroup-id:
+      $ref: '#/components/schemas/common-id'
+    Partsgroup:
+      allOf:
+        - $ref: '#/components/schemas/NewPartsgroup'
+        - type: object
+          required:
+            - id
+          properties:
+            id:
+              $ref: '#/components/schemas/partsgroup-id'
+    NewPartsgroup:
+      type: object
+      required:
+        - description
+      properties:
+        description:
+          type: string
+        parent:
+          type: integer
+          format: int64
+          minimum: 1
+          nullable: true
     pricegroup-id:
       $ref: '#/components/schemas/common-id'
     Pricegroup:
@@ -883,6 +1328,22 @@ components:
         description:
           type: string
   examples:
+    validPartsgroups:
+      summary: Valid Partsgroups (collection response)
+      description: Parts groups collection response
+      value:
+        _links: []
+        items:
+        - id: 1
+          parent: null
+          description: Partsgroup1
+    validPartsgroup:
+      summary: Valid Partsgroup
+      description: Partsgroup entry
+      value:
+        id: 1
+        parent: null
+        description: Partsgroup1
     validPricegroups:
       summary: Valid pricegroups (collection response)
       description: Pricegroups collection response
