@@ -56,12 +56,6 @@ sub _default_settings {
                 label => $locale->text('Base Currency'),
                 type => 'SELECT_ONE', },
               { name => 'weightunit', label => $locale->text('Weight Unit') },
-              { name => 'default_country',
-                label => $locale->text('Default Country'),
-                type => 'SELECT_ONE', },
-              { name => 'default_language',
-                label => $locale->text('Default Language'),
-                type => 'SELECT_ONE', },
               { name => 'format',
                 type => 'SELECT_ONE',
                 label => $locale->text('Default Format'), },
