@@ -56,12 +56,20 @@ sub search {
     if (any { $request->{"inc_$_"} } qw(so po is ir quo rfq) ) {
        $request->{col_ordnumber} = 1;
        return $request->render_report(
-           LedgerSMB::Report::Inventory::History->new(%$request)
-           );
+           LedgerSMB::Report::Inventory::History->new(
+               %$request,
+               formatter_options => $request->formatter_options,
+               from_date => $request->parse_date( $request->{from_date} ),
+               to_date => $request->parse_date( $request->{to_date} ),
+           ));
     }
     return $request->render_report(
-        LedgerSMB::Report::Inventory::Search->new(%$request)
-        );
+        LedgerSMB::Report::Inventory::Search->new(
+            %$request,
+            formatter_options => $request->formatter_options,
+            from_date => $request->parse_date( $request->{from_date} ),
+            to_date => $request->parse_date( $request->{to_date} ),
+        ));
 }
 
 =item search_partsgroups
@@ -74,8 +82,10 @@ for a prefix search
 sub search_partsgroups {
     my ($request) = @_;
     return $request->render_report(
-        LedgerSMB::Report::Inventory::Partsgroups->new(%$request)
-        );
+        LedgerSMB::Report::Inventory::Partsgroups->new(
+            %$request,
+            formatter_options => $request->formatter_options
+        ));
 }
 
 =item search_pricegroups
@@ -88,8 +98,10 @@ for a prefix search
 sub search_pricegroups {
     my ($request) = @_;
     return $request->render_report(
-        LedgerSMB::Report::Inventory::Pricegroups->new(%$request)
-        );
+        LedgerSMB::Report::Inventory::Pricegroups->new(
+            %$request,
+            formatter_options => $request->formatter_options
+        ));
 }
 
 =item inventory_activity
@@ -101,8 +113,12 @@ This routine runs the inventory activity report/
 sub inventory_activity {
     my ($request) = @_;
     return $request->render_report(
-        LedgerSMB::Report::Inventory::Activity->new(%$request)
-        );
+        LedgerSMB::Report::Inventory::Activity->new(
+            %$request,
+            formatter_options => $request->formatter_options,
+            from_date => $request->parse_date( $request->{from_date} ),
+            to_date => $request->parse_date( $request->{to_date} ),
+        ));
 }
 
 =item cogs_lines
@@ -114,8 +130,12 @@ Runs the cogs lines report.
 sub cogs_lines {
     my ($request) = shift;
     return $request->render_report(
-        LedgerSMB::Report::Invoices::COGS->new(%$request)
-        );
+        LedgerSMB::Report::Invoices::COGS->new(
+            %$request,
+            formatter_options => $request->formatter_options,
+            from_date => $request->parse_date( $request->{from_date} ),
+            to_date => $request->parse_date( $request->{to_date} ),
+        ));
 }
 
 =back
