@@ -27,7 +27,6 @@ use LedgerSMB::Report::Unapproved::Batch_Overview;
 use LedgerSMB::Report::Unapproved::Batch_Detail;
 use LedgerSMB::Scripts::payment;
 use LedgerSMB::Scripts::reports;
-use LedgerSMB::Setting;
 
 use LedgerSMB::old_code qw(dispatch);
 
@@ -266,7 +265,7 @@ Displays all vouchers from the batch by type, and includes amount.
 
 sub get_batch {
     my ($request)  = @_;
-    my $setting =  LedgerSMB::Setting->new(%$request);
+    my $setting =  $request->setting;
     $request->open_form;
 
     $request->{hiddens} = { batch_id => $request->{batch_id} };
@@ -292,6 +291,7 @@ sub single_batch_approve {
     delete $request->{language}; # only applicable for printing of batches
     if ($request->close_form){
         my $batch = LedgerSMB::Batch->new(%$request);
+        $batch->get;
         $batch->post;
         return list_batches($request);
     } else {
