@@ -61,21 +61,24 @@ sub _wrap_html {
     my ($request) = shift;
 
     my $template = $request->{_wire}->get('ui');
-    unshift @HTML, $template->render_string(
-        $request,
-        'setup/upgrade/preamble',
-        {
-            check_id => _check_hashid( $failing_check ),
-            database => $request->{database},
-            resubmit_action => $request->{resubmit_action},
-            action_url => $request->{_uri}->as_string,
-        });
-
-    $template = $request->{_wire}->get('ui');
-    push @HTML, $template->render_string($request,
-                                         'setup/upgrade/epilogue');
-
-    return \@HTML;
+    return [
+        $template->render_string(
+            $request,
+            'setup/upgrade/wrapper',
+            {
+                action_url      => $request->{_uri}->as_string,
+                check_id        => _check_hashid( $failing_check ),
+                database        => $request->{database},
+                resubmit_action => $request->{resubmit_action},
+                # note: the line below works because the upgrade
+                # has completed when this wrapper is being run
+                run_id          => $request->{run_id},
+                title           => $failing_check->{title}
+            },
+            {
+                validation_html => join("\n", @HTML)
+            })
+        ];
 }
 
 sub _format_confirm {
@@ -115,9 +118,7 @@ sub _format_describe {
     push @HTML, $template->render_string(
         $request,
         'setup/upgrade/describe',
-        {
-            title => $check->{title},
-        },
+        { }, # no template variables which need HTML encoding
         {
             description => markdown($msg),
         });
