@@ -377,49 +377,47 @@ sub display_form
 
     #Form footer  Begins------------------------------------------
 
-    $form->{_setting_decimal_places} //= LedgerSMB::Setting->new(%$form)->get('decimal_places');
+    $form->{_setting_decimal_places} //= $form->get_setting('decimal_places');
     for (qw(totaldebit totalcredit)) {
         $form->{$_} =
-            $form->format_amount( \%myconfig, $form->{$_}, $form->{_setting_decimal_places}, "0" );
+            $form->format_amount( \%myconfig, $form->{$_},
+                                  $form->{_setting_decimal_places}, "0" );
     }
 
   $transdate = $form->datetonum( \%myconfig, $form->{transdate} );
   my @buttons;
-  if ( !$form->{readonly} ) {
-      %button_types = (
-          print => 'lsmb/PrintButton'
-          );
-      for my $action_name ( $wf->get_current_actions ) {
-          my $action = $wf->get_action( $action_name );
+    %button_types = (
+        print => 'lsmb/PrintButton'
+        );
+    for my $action_name ( $wf->get_current_actions ) {
+        my $action = $wf->get_action( $action_name );
 
-          next if ($action->ui // '') eq 'none';
-          push @buttons, {
-              ndx   => $action->order,
-              name  => $action->name,
-              text => $locale->maketext($action->text),
-              doing => ($action->doing ? $locale->maketext($action->doing) : ''),
-              done  => ($action->done ? $locale->maketext($action->done) : ''),
-              type  => $button_types{$action->ui},
-              tooltip => ($action->short_help ? $locale->maketext($action->short_help) : '')
-          };
-      }
+        next if ($action->ui // '') eq 'none';
+        push @buttons, {
+            ndx   => $action->order,
+            name  => $action->name,
+            text => $locale->maketext($action->text),
+            doing => ($action->doing ? $locale->maketext($action->doing) : ''),
+            done  => ($action->done ? $locale->maketext($action->done) : ''),
+            type  => $button_types{$action->ui},
+            tooltip => ($action->short_help ? $locale->maketext($action->short_help) : '')
+        };
+    }
 
-      @buttons = map {
-          {
-              name => '__action',
-              value => $_->{name},
-              text => $_->{text},
-              type => 'submit',
-              class => $_->{class} // 'submit',
-              order => $_->{ndx},
-              'data-lsmb-doing' => $_->{doing},
-              'data-lsmb-done' => $_->{done},
-              'data-dojo-type' => $_->{type} // 'dijit/form/Button',
-              'data-dojo-props' => $_->{type} ? 'minimalGET: false' : '',
-          }
-      }
-      sort { $a->{ndx} <=> $b->{ndx} } @buttons;
-  }
+    @buttons = map {
+        {
+            name => '__action',
+            value => $_->{name},
+            text => $_->{text},
+            type => 'submit',
+            class => $_->{class} // 'submit',
+            order => $_->{ndx},
+            'data-lsmb-doing' => $_->{doing},
+            'data-lsmb-done' => $_->{done},
+            'data-dojo-type' => $_->{type} // 'dijit/form/Button',
+            'data-dojo-props' => $_->{type} ? 'minimalGET: false' : '',
+        }
+    } sort { $a->{ndx} <=> $b->{ndx} } @buttons;
 
   $form->{recurringset}=0;
   if ( $form->{recurring} ) {
@@ -507,7 +505,7 @@ sub display_row {
   $form->{totaldebit}  = 0;
   $form->{totalcredit} = 0;
 
-    $form->{_setting_decimal_places} //= LedgerSMB::Setting->new(%$form)->get('decimal_places');
+    $form->{_setting_decimal_places} //= $form->get_setting('decimal_places');
     for my $i ( 0 .. $form->{rowcount} ) {
 
         my $temphash1;
@@ -778,7 +776,7 @@ sub check_balanced {
 }
 
 sub save_as_new {
-    for (qw(id printed emailed)) { delete $form->{$_} }
+    for (qw(id)) { delete $form->{$_} }
     if ($form->{workflow_id}) {
         my $wf = $form->{_wire}->get('workflows')->fetch_workflow(
             'GL', $form->{workflow_id}
@@ -809,7 +807,8 @@ sub print {
         my $amount_fx = $form->{"debit_fx_0"} eq "" ? $form->{"credit_fx_0"} : $form->{"debit_fx_0"};
 
         $form->{exchange_rate} = $form->parse_amount( \%myconfig,$amount) / $form->parse_amount( \%myconfig,$amount_fx);
-        $form->{exchange_rate} = $form->format_amount( \%myconfig, $form->{exchange_rate}, LedgerSMB::Setting->new(%$form)->get('decimal_places') );
+        $form->{exchange_rate} = $form->format_amount( \%myconfig, $form->{exchange_rate},
+                                                       $form->get_setting('decimal_places') );
 
         $form->{curr} = $form->{"curr_0"};;
 
