@@ -44,7 +44,6 @@ use LedgerSMB::IIAA;
 use LedgerSMB::OE;
 use LedgerSMB::Tax;
 use LedgerSMB::Template;
-use LedgerSMB::Setting;
 use LedgerSMB::Legacy_Util;
 use LedgerSMB::File;
 use List::Util qw(max reduce);
@@ -291,7 +290,7 @@ qq|<option value="$ref->{partsgroup}--$ref->{id}">$ref->{partsgroup}\n|;
 
     $spc = substr( $myconfig{numberformat}, -3, 1 );
     my $moneyplaces =
-        $form->{_setting_decimal_places} //= LedgerSMB::Setting->new(%$form)->get('decimal_places');
+        $form->{_setting_decimal_places} //= $form->get_setting('decimal_places');
     foreach my $i ( 1 .. max($numrows, $min_lines)) {
         next if $readonly and not $form->{"partnumber_$i"};
 
@@ -593,75 +592,6 @@ qq|<td><input data-dojo-type="dijit/form/TextBox" id="notes_$i" name="notes_$i"
     $form->hide_form(qw(audittrail));
 }
 
-sub new_item {
-
-    # change callback
-    $form->{old_callback} = $form->escape( $form->{callback}, 1 );
-    $form->{callback} =
-      $form->escape( "$form->{script}?__action=display_form", 1 );
-
-    # save all other form variables in a previousform variable
-    if ( !$form->{previousform} ) {
-        foreach my $key ( keys %$form ) {
-
-            # escape ampersands
-            $form->{$key} =~ s/&/%26/g;
-            $form->{previousform} .= qq|$key=$form->{$key}&|;
-        }
-        chop $form->{previousform};
-        $form->{previousform} = $form->escape( $form->{previousform}, 1 );
-    }
-
-    $i = $form->{rowcount};
-    for (qw(partnumber description)) {
-        $form->{"${_}_$i"} = $form->quote( $form->{"${_}_$i"} );
-    }
-
-    $form->header;
-
-    print qq|
-<body class="lsmb">
-
-<h4 class=error>| . $locale->text('Item not on file!') . qq|</h4>|;
-
-    print qq|
-<h4>| . $locale->text('What type of item is this?') . qq|</h4>
-
-<form method="post" data-dojo-type="lsmb/Form" action="ic.pl">
-
-<p>
-
-  <input class=radio type=radio data-dojo-type="dijit/form/RadioButton" name=item value=part checked>&nbsp;|
-          . $locale->text('Part') . qq|<br>
-  <input class=radio type=radio data-dojo-type="dijit/form/RadioButton" name=item value=service>&nbsp;|
-          . $locale->text('Service')
-
-          . qq|
-<input type=hidden name=partnumber value="$form->{"partnumber_$i"}">
-<input type=hidden name=description value="$form->{"description_$i"}">
-<input type=hidden name=nextsub value=add>
-<input type=hidden name=action value=add>
-|;
-
-    $form->hide_form(qw(previousform rowcount path login sessionid));
-
-    print qq|
-<p>
-<button data-dojo-type="dijit/form/Button" class="submit" type="submit" name="__action" value="continue">|
-          . $locale->text('Continue')
-          . qq|</button>
-</form>
-|;
-
-    print qq|
-</body>
-</html>
-|;
-
-    $form->finalize_request();
-
-}
-
 sub display_form {
     my ($want_return) = @_;
     $form->close_form();
@@ -1040,7 +970,7 @@ sub quotation {
 
 sub create_form {
 
-    for (qw(id printed emailed workflow_id)) { delete $form->{$_} }
+    for (qw(id workflow_id)) { delete $form->{$_} }
 
     $form->{script} = 'oe.pl';
 
@@ -1404,17 +1334,6 @@ sub print_form {
         $form->{OUT} =~ s/<%(fax)%>/<%$form->{vc}$1%>/;
         $form->{OUT} =~ s/<%(.*?)%>/$form->{$1}/g;
         $form->{printmode} = '|-';
-
-        if ( $form->{printed} !~ /$form->{formname}/ ) {
-
-            $form->{printed} .= " $form->{formname}";
-            $form->{printed} =~ s/^ //;
-
-            $form->update_status;
-        }
-
-        $old_form->{printed} = $form->{printed} if %$old_form;
-
     } elsif ( $form->{media} eq 'email' ) {
         $form->{plainpaper} = 1;
         $output_options{filename} = $form->{formname} . '-'. $form->{"${inv}number"};
