@@ -48,7 +48,6 @@ use LedgerSMB::IR;
 use LedgerSMB::IS;
 use LedgerSMB::Magic qw(OEC_SALES_ORDER OEC_PURCHASE_ORDER);
 use LedgerSMB::PE;
-use LedgerSMB::Setting;
 use LedgerSMB::Tax;
 use LedgerSMB::Legacy_Util;
 
@@ -424,6 +423,7 @@ sub form_header {
     }
 
     if ( $form->{type} !~ /_quotation$/ ) {
+        $form->{transdate} ||= 'today';
         $ordnumber = qq|
           <tr class="ordnumber-row">
         <th width=70% align=right nowrap>| . $locale->text('Order Number') . qq|</th>
@@ -433,7 +433,7 @@ sub form_header {
           </tr>
           <tr class="transdate-row">
         <th align=right nowrap>| . $locale->text('Order Date') . qq|</th>
-        <td><input class="date" data-dojo-type="lsmb/DateTextBox"name=transdate size=11 title="$myconfig{dateformat}" value="$form->{transdate}" id="transdate" data-dojo-props="defaultIsToday:true"></td>
+        <td><lsmb-date name=transdate size=11 title="$myconfig{dateformat}" value="$form->{transdate}" id="transdate"></lsmb-date></td>
           </tr>
           <tr class="reqdate-row">
         <th align=right nowrap=true>| . $locale->text('Required by') . qq|</th>
@@ -448,7 +448,7 @@ sub form_header {
 
         $n = ( $form->{creditremaining} < 0 ) ? "0" : "1";
 
-        if (LedgerSMB::Setting->new(%$form)->get('show_creditlimit')){
+        if ($form->get_setting('show_creditlimit')){
         $creditremaining = qq|
           <tr>
         <td></td>
@@ -605,7 +605,7 @@ sub form_header {
     }
     $form->hide_form(qw(entity_control_code meta_number tax_id address city zipcode state country));
     $form->hide_form(
-        qw(id type printed emailed vc title discount creditlimit creditremaining tradediscount business recurring form_id nextsub
+        qw(id type vc title discount creditlimit creditremaining tradediscount business recurring form_id nextsub
    lock_description)
     );
 
@@ -685,35 +685,33 @@ sub form_header {
 <input type=hidden name="${_}_description" value="$form->{"${_}_description"}">
 |;
     }
-    if ( !$form->{readonly} ) {
-        print "<tr><td>";
+    print "<tr><td>";
 
-        %button_types = (
-            print => 'lsmb/PrintButton'
-            );
-        %button = ();
-        for my $action_name ( $wf->get_current_actions( 'main') ) {
-            my $action = $wf->get_action( $action_name );
+    %button_types = (
+        print => 'lsmb/PrintButton'
+        );
+    %button = ();
+    for my $action_name ( $wf->get_current_actions( 'main') ) {
+        my $action = $wf->get_action( $action_name );
 
-            next if ($action->ui // '') eq 'none';
-            $button{$action_name} = {
-                ndx   => $action->order,
-                value => $locale->maketext($action->text),
-                doing => ($action->doing ? $locale->maketext($action->doing) : ''),
-                done  => ($action->done ? $locale->maketext($action->done) : ''),
-                type  => $button_types{$action->ui},
-                tooltip => ($action->short_help ? $locale->maketext($action->short_help) : '')
-            };
-        }
-
-        for ( sort { $button{$a}->{ndx} <=> $button{$b}->{ndx} }
-              keys %button ) {
-            $form->print_button( \%button, $_ );
-        }
-
-        $form->hide_form(qw(defaultcurrency workflow_id));
-        print "</td></tr>";
+        next if ($action->ui // '') eq 'none';
+        $button{$action_name} = {
+            ndx   => $action->order,
+            value => $locale->maketext($action->text),
+            doing => ($action->doing ? $locale->maketext($action->doing) : ''),
+            done  => ($action->done ? $locale->maketext($action->done) : ''),
+            type  => $button_types{$action->ui},
+            tooltip => ($action->short_help ? $locale->maketext($action->short_help) : '')
+        };
     }
+
+    for ( sort { $button{$a}->{ndx} <=> $button{$b}->{ndx} }
+          keys %button ) {
+        $form->print_button( \%button, $_ );
+    }
+
+    $form->hide_form(qw(defaultcurrency workflow_id));
+    print "</td></tr>";
 }
 
 sub form_footer {
@@ -747,7 +745,7 @@ qq|<textarea data-dojo-type="dijit/form/Textarea" id=intnotes name=intnotes rows
 |;
     }
 
-    $form->{_setting_decimal_places} = LedgerSMB::Setting->new(%$form)->get('decimal_places');
+    $form->{_setting_decimal_places} = $form->get_setting('decimal_places');
     if ( !$form->{taxincluded} ) {
         foreach my $item (keys %{$form->{taxes}}) {
             my $taccno = $item;
@@ -1328,12 +1326,12 @@ sub delete {
     # $form->header;
 
     if ( $form->{type} =~ /_order$/ ) {
-        $msg = $locale->text('Are you sure you want to delete Order Number');
+        $msg = $locale->text('Are you sure you want to delete Order Number?');
         $ordnumber = 'ordnumber';
     }
     else {
         $msg =
-          $locale->text('Are you sure you want to delete Quotation Number');
+          $locale->text('Are you sure you want to delete Quotation Number?');
         $ordnumber = 'quonumber';
     }
 
@@ -1468,7 +1466,7 @@ sub invoice {
     }
     my $lib = uc($script);
 
-    for (qw(id subject message printed emailed)) { delete $form->{$_} }
+    for (qw(id subject message)) { delete $form->{$_} }
     $form->{ $form->{vc} } =~ s/--.*//g;
     $form->{type} = "invoice";
 
@@ -1511,7 +1509,7 @@ sub invoice {
     $form->{duedate} = $form->current_date( \%myconfig, $form->{transdate},
                                             $form->{terms} * 1 );
 
-    for (qw(id subject message printed emailed audittrail)) {
+    for (qw(id subject message audittrail)) {
         delete $form->{$_};
     }
 
@@ -1660,7 +1658,7 @@ sub create_backorder {
     }
 
     # clear flags
-    for (qw(id subject message cc bcc printed emailed audittrail)) {
+    for (qw(id subject message cc bcc audittrail)) {
         delete $form->{$_};
     }
 
@@ -1694,7 +1692,7 @@ sub save_as_new {
     # orders don't have a quonumber
     # quotes don't have an ordnumber
     $form->{old_workflow_id} = $form->{workflow_id};
-    for (qw(closed id printed emailed ordnumber quonumber workflow_id)) {
+    for (qw(closed id ordnumber quonumber workflow_id)) {
         delete $form->{$_}
     }
     &_save;
@@ -1705,7 +1703,7 @@ sub print_and_save_as_new {
     # orders don't have a quonumber
     # quotes don't have an ordnumber
     $form->{old_workflow_id} = $form->{workflow_id};
-    for (qw(closed id printed emailed ordnumber quonumber workflow_id)) {
+    for (qw(closed id ordnumber quonumber workflow_id)) {
         delete $form->{$_}
     }
     &_print_and_save;
@@ -1804,7 +1802,7 @@ sub display_ship_receive {
 <input type=hidden name=display_form value=display_ship_receive>
 |;
 
-    $form->hide_form(qw(id type media format printed emailed vc));
+    $form->hide_form(qw(id type media format vc));
 
     print qq|
 <input type=hidden name="old$form->{vc}" value="$form->{"old$form->{vc}"}">
@@ -2350,7 +2348,7 @@ sub generate_purchase_orders {
 
     # flatten array
     $i = 0;
-    $form->{_setting_decimal_places} = LedgerSMB::Setting->new(%$form)->get('decimal_places');
+    $form->{_setting_decimal_places} = $form->get_setting('decimal_places');
     foreach my $parts_id (
         sort {
             $form->{orderitems}{$a}{partnumber}
